#ifndef __SCANIPC_H__
#define __SCANIPC_H__
#ifdef __cplusplus
extern "C" {
#endif

/*
 * scanipc.h
 *
 *      Inter-process communication stuff between scanner apps and scanner
 * drivers.
 *
 * Copyright 1992, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics,
 * Inc.; the contents of this file may not be disclosed to third
 * parties, copied or duplicated in any form, in whole or in part,
 * without the prior written permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to
 * restrictions as set forth in subdivision (c)(1)(ii) of the Rights
 * in Technical Data and Computer Software clause at DFARS
 * 252.227-7013, and/or in similar or successor clauses in the FAR,
 * DOD or NASA FAR Supplement. Unpublished - rights reserved under the
 * Copyright Laws of the United States.
 */

#ident "$Revision: 1.12 $"

/*
 * Required functions
 */
#define SCN_INITOK 0
#define SCN_DIE 1
#define SCN_MINMAXRES 2
#define SCN_NRES 3
#define SCN_RES 4
#define SCN_NTYPES 5
#define SCN_TYPES 6
#define SCN_PAGESIZE 7
#define SCN_SETUP 8
#define SCN_SCAN 9
#define SCN_ABORT 10
#define SCN_GETSIZE 11
#define SCN_FEEDERGETFLAGS 12
#define SCN_FEEDERSETFLAGS 13
#define SCN_FEEDERADVANCE 14
#define SCN_FEEDERREADY 15
#define SCN_GETVERSION 16
#define SCN_GETSAVEOPTLEN 17
#define SCN_GETSAVEOPT 18
#define SCN_SETSAVEOPT 19

/*
 * Scanner specific options start here
 */
#define SCN_SCANSPECIFIC 200

#if defined(_LANGUAGE_C) || defined(_LANGUAGE_C_PLUS_PLUS)

typedef struct tag_scminmaxres {
    float minx, miny, maxx, maxy;
} SCMINMAXRES;

typedef struct tag_scsetup {
    int preview;
    SCDATATYPE type;
    int rmetric;
    float xres, yres;
    int wmetric;
    float x, y, width, height;
} SCSETUP;

typedef struct tag_scsize {
    long xbytes, xpixels, ysize;
} SCSIZE;

typedef struct tag_scwindow {
    float x, y, width, height;
} SCWINDOW;

typedef struct tag_scanopt {
    int out, in;
} SCANOPT;

typedef struct tag_cmdhdr {
    unsigned int cmd, arglen;
} CMDHDR;

typedef struct tag_replhdr {
    int len, errno;
} REPLHDR;

int SCScanCmd(SCANNER *s, int cmd, void *args, int arglen, void *res,
	      int reslen);

SCANOPT * SCGetScanOpt(int *argc, char *argv[]);

int SCScanOpt(SCANOPT *s, int cmd, void *args, int arglen,
	      void *res, int reslen);


#endif /* C || C++ */

#ifdef __cplusplus
}
#endif
#endif /* !__SCANIPC_H__ */
